/***************************************************************************
 *   Copyright (C) 2005 by Joe Ferris                                      *
 *   jferris@optimistictech.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef KATAPULTITEM_H
#define KATAPULTITEM_H

#include <tqobject.h>

#include "katapultaction.h"

class TQPixmap;
class TQString;

/**
@author Joe Ferris
*/
class KDE_EXPORT KatapultItem : public TQObject {
	Q_OBJECT
  
public:

	KatapultItem();
	virtual ~KatapultItem();
	
	virtual TQString text() const;
	virtual TQPixmap icon(int) const;

signals:
	void itemChanged();
};

#endif
